﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MontoyaTech.Rest.Net
{
    /// <summary>
    /// A class to help convert route arguments.
    /// </summary>
    internal class RouteArgumentConverter
    {
        /// <summary>
        /// Converts a string to a given type if possible. Otherwise returns default of T.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="input"></param>
        /// <returns></returns>
        public static T Convert<T>(string input)
        {
            var result = Convert(typeof(T), input);

            if (result == null)
                return default(T);

            return (T)result;
        }

        /// <summary>
        /// Converts a string to a given type if possible. Otherwise returns null.
        /// </summary>
        /// <param name="type"></param>
        /// <param name="input"></param>
        /// <returns></returns>
        public static object Convert(Type type, string input)
        {
            var typeCode = Type.GetTypeCode(type);

            if (type.IsEnum)
            {
                return Enum.Parse(type, input, true);
            }
            else if (typeCode == TypeCode.String)
            {
                return input;
            }
            else if (typeCode == TypeCode.Object)
            {
                var castOperator = type.GetMethod("op_Explicit", new[] { typeof(string) });

                if (castOperator == null)
                    return null;

                return castOperator.Invoke(null, new[] { input });
            }
            else if (typeCode == TypeCode.Double)
            {
                double.TryParse(input, out double result);

                return result;
            }
            else if (typeCode == TypeCode.Single)
            {
                float.TryParse(input, out float result);

                return result;
            }
            else if (typeCode == TypeCode.Decimal)
            {
                decimal.TryParse(input, out decimal result);

                return result;
            }
            else if (typeCode == TypeCode.Int64)
            {
                long.TryParse(input, out long result);

                return result;
            }
            else if (typeCode == TypeCode.Int32)
            {
                int.TryParse(input, out int result);

                return result;
            }
            else if (typeCode == TypeCode.Int16)
            {
                short.TryParse(input, out short result);

                return result;
            }
            else if (typeCode == TypeCode.SByte)
            {
                sbyte.TryParse(input, out sbyte result);

                return result;
            }
            else if (typeCode == TypeCode.UInt64)
            {
                ulong.TryParse(input, out ulong result);

                return result;
            }
            else if (typeCode == TypeCode.UInt32)
            {
                uint.TryParse(input, out uint result);

                return result;
            }
            else if (typeCode == TypeCode.UInt16)
            {
                ushort.TryParse(input, out ushort result);

                return result;
            }
            else if (typeCode == TypeCode.Byte)
            {
                byte.TryParse(input, out byte result);

                return result;
            }
            else if (typeCode == TypeCode.Boolean)
            {
                if (input == "f" || input == "0" || input == "F")
                    return false;

                bool.TryParse(input, out bool result);

                return result;
            }
            else if (typeCode == TypeCode.DateTime)
            {
                DateTime.TryParse(input, out DateTime result);

                return result;
            }
            else if (typeCode == TypeCode.Char)
            {
                char.TryParse(input, out char result);

                return result;
            }

            return null;
        }
    }
}