﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MontoyaTech.Rest.Net
{
    /// <summary>
    /// The outline of an attribute that controls what group a route belongs to.
    /// </summary>
    [AttributeUsage(AttributeTargets.Class | AttributeTargets.Method, AllowMultiple = false, Inherited = true)]
    public class RouteGroup : Attribute
    {
        /// <summary>
        /// The name of the group this Route belongs to.
        /// </summary>
        public string Name = null;

        /// <summary>
        /// Creates a new default route group.
        /// </summary>
        public RouteGroup() { }

        /// <summary>
        /// Creates a new route group with the name of the group.
        /// </summary>
        /// <param name="name"></param>
        public RouteGroup(string name)
        {
            if (string.IsNullOrWhiteSpace(name))
                throw new ArgumentException("Must not be null or empty", nameof(name));

            this.Name = name;
        }
    }
}
