﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MontoyaTech.Rest.Net
{
    /// <summary>
    /// The outline of an attribute that defines a routes response type.
    /// </summary>
    [AttributeUsage(AttributeTargets.Method, AllowMultiple = false, Inherited = true)]
    public class RouteResponse : Attribute
    {
        /// <summary>
        /// The type of the request.
        /// </summary>
        public Type ResponseType = null;

        /// <summary>
        /// Whether or not the response is Json Serialized, default is true.
        /// </summary>
        public bool Json = true;

        /// <summary>
        /// Whether or not the response is passed as a parameter to the route function. Default is false.
        /// </summary>
        public bool Parameter = false;

        /// <summary>
        /// Whether or not the response is a dynamic type. Default is false.
        /// </summary>
        public bool Dynamic = false;

        /// <summary>
        /// Creates a default route response.
        /// </summary>
        public RouteResponse() { }

        /// <summary>
        /// Creates a route response with the response type.
        /// </summary>
        /// <param name="responseType"></param>
        public RouteResponse(Type responseType)
        {
            this.ResponseType = responseType;
        }
    }
}
